any_duplicates: Check whether any priors or attributes are specified with a...

View source: R/assertions.R

any_duplicatesR Documentation

Check whether any priors or attributes are specified with a value more than once

Description

Check whether any priors or attributes are specified with a value more than once

Usage

any_duplicates(x)

Arguments

x

A list of utility expressions

Value

A boolean equal to 'TRUE' if specified more than once.


spdesign documentation built on July 2, 2026, 5:06 p.m.