as_whole_word: Match names as whole words

View source: R/utils.R

as_whole_wordR Documentation

Match names as whole words

Description

Creates regular expressions that match names as whole words, so that e.g. x1 does not match x10, b_x1 or alt1_x1. Names in the utility functions only contain letters, digits and underscores.

Usage

as_whole_word(name)

Arguments

name

A character vector of names

Value

A character vector of regular expressions


spdesign documentation built on Oct. 6, 2026, 9:07 a.m.