attribute_levels: Generic for getting the attributes and levels from the...

View source: R/parsing.R

attribute_levelsR Documentation

Generic for getting the attributes and levels from the utility function

Description

Generic for getting the attributes and levels from the utility function

Usage

attribute_levels(x)

Arguments

x

An object of class utility

Value

A named list of attribute levels


spdesign documentation built on July 2, 2026, 5:06 p.m.