View source: R/candidate-set.R
| combine_profiles | R Documentation |
Combine the profiles of a group of exchangeable alternatives
combine_profiles(n, k, allow_reversed_pairs)
n |
The number of profiles of each alternative in the group |
k |
The number of alternatives in the group |
allow_reversed_pairs |
If TRUE, include the profiles of exchangeable alternatives in every order, e.g. both A versus B and B versus A. This also applies to sets of three or more exchangeable alternatives. The default is FALSE. |
A matrix with one row per combination and one column per alternative, giving the rows of the profiles to combine
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.