cor: Correlation

View source: R/methods.R

corR Documentation

Correlation

Description

Calculate the correlation of the design. The function gets the design from the design object before passing it to cor from stats. This is a wrapper around cor.

Usage

cor(x, ...)

Arguments

x

A model object of class 'spdesign'

...

Additional parameters passed to the function

Details

Note that when your design includes constants, the function will print a warning because the standard deviation of a constant is 0.

Value

A matrix with correlations


spdesign documentation built on July 2, 2026, 5:06 p.m.