define_profiles: Define the profiles of each alternative

View source: R/candidate-set.R

define_profilesR Documentation

Define the profiles of each alternative

Description

Defines the profiles of each alternative as the full factorial of its attribute levels, with the exclusions that only refer to that alternative applied, and finds the groups of exchangeable alternatives. See build_candidate_set.

Usage

define_profiles(utility, exclusions = list())

Arguments

utility

A named list of utility functions. See the examples and the vignette for examples of how to define these correctly for different types of experimental designs.

exclusions

A list of exclusions Often this list will be pulled directly from the list of options or it is a modified list of exclusions

Value

A list with the profiles of each alternative, the groups of exchangeable alternatives and the exclusions across alternatives


spdesign documentation built on Oct. 6, 2026, 9:07 a.m.