exclude: Exclude rows from the candidate set

View source: R/exclusions-and-conditions.R

excludeR Documentation

Exclude rows from the candidate set

Description

Each exclusion is evaluated with the columns of the candidate set as variables, and the rows where it is TRUE are removed.

Usage

exclude(candidate_set, exclusions)

Arguments

candidate_set

A matrix or data frame in the "wide" format containing all permitted combinations of attributes. The default is NULL. If no candidate set is provided, then it is built from the utility functions subject to specified exclusions with build_candidate_set. This is passed in as an object and not a character string. The candidate set will be expanded to include zero columns to consider alternative specific attributes.

exclusions

A list of exclusions Often this list will be pulled directly from the list of options or it is a modified list of exclusions

Value

A restricted candidate set


spdesign documentation built on Oct. 6, 2026, 9:07 a.m.