| extract_all_names | R Documentation |
Extracts all parameter and attribute names from the utility function.
This is a wrapper around str_extract_all with a specified
boundary. The function also calls remove_all_brackets to
ensure that if a word is used inside a square bracket, e.g. seq, it is not
extracted.
extract_all_names(string, simplify = FALSE)
string |
A character string |
simplify |
If TRUE return as a vector. Default is FALSE. |
A name is a word that starts with a letter and is not followed by an opening round bracket. This avoids extracting numbers, e.g. the 2 in I(x1^2), and functions such as the interaction operator I() as attributes.
A list or vector with all names
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.