extract_named_values: Extracts the named values of the utility function

View source: R/extract.R

extract_named_valuesR Documentation

Extracts the named values of the utility function

Description

The function extracts the named values of the supplied utility function.

Usage

extract_named_values(string)

Arguments

string

A character string

Value

A named list of parameter and attribute values. Each list element is named and can contain a single prior, a list with a mean and sd, or a vector with attribute levels


spdesign documentation built on July 2, 2026, 5:06 p.m.