extract_values: Extract the value argument(s)

View source: R/extract.R

extract_valuesR Documentation

Extract the value argument(s)

Description

Extracts the value argument(s) of the supplied string. The value argument is defined as the characters between [] string.

Usage

extract_values(string, simplify = FALSE)

Arguments

string

A character string

simplify

If TRUE return as a vector. Default is FALSE.

Value

A vector or list with the extracted value arguments


spdesign documentation built on July 2, 2026, 5:06 p.m.