full_factorial: Generate the full factorial

View source: R/full-factorial.R

full_factorialR Documentation

Generate the full factorial

Description

This function is deprecated and will be removed in a future version. Use build_candidate_set to build a candidate set from the utility functions, or expand.grid to create the full factorial of a list of attributes with levels that are different from those in the utility functions.

Usage

full_factorial(attrs)

Arguments

attrs

A named list of attributes and their levels

Details

The function is a wrapper around expand.grid and generates the full factorial given the supplied attributes.

Value

A data frame containing the full factorial

Examples

attrs <- list(
  a1 = 1:5,
  a2 = c(0, 1)
)

# Instead of full_factorial(attrs)
expand.grid(attrs)


spdesign documentation built on Oct. 6, 2026, 9:07 a.m.