invalid_dummy_coding: Find dummy-coded attributes that are not correctly specified

View source: R/assertions.R

invalid_dummy_codingR Documentation

Find dummy-coded attributes that are not correctly specified

Description

Dummy-coded attributes must have the levels 1, 2, ..., K, where 1 is the base level, and exactly K - 1 priors, one for each level except the base level. Only the number of levels matters for the design, and using 1, 2, ..., K ensures that the expanded dummy-coded attributes and priors are named and ordered consistently.

Usage

invalid_dummy_coding(x)

Arguments

x

An object of class utility

Value

A character vector with the names of dummy-coded attributes that are not correctly specified. Empty if there are none.


spdesign documentation built on Oct. 6, 2026, 9:07 a.m.