pair_param_terms: Pair the terms of the utility functions with their parameters

View source: R/parsing.R

pair_param_termsR Documentation

Pair the terms of the utility functions with their parameters

Description

Splits each updated utility function into its additive terms and pairs each term with its parameter, e.g. "b_x1x2 * I(alt1_x1 * alt1_x2)". The function is used on the output of update_utility, where dummy-coded attributes are already expanded.

Usage

pair_param_terms(x)

Arguments

x

A list of updated utility functions returned by update_utility

Value

A list with one named character vector per utility function. The values are the parameter names and the names are the terms, both without whitespace.


spdesign documentation built on Oct. 6, 2026, 9:07 a.m.