probabilities: Calculate the probabilities of the design

View source: R/probabilities.R

probabilitiesR Documentation

Calculate the probabilities of the design

Description

Will take the design object and calculate the probabilities of each alternative and choice tasks.

Usage

probabilities(x)

Arguments

x

An 'spdesign' object.

Details

Using Bayesian priors the average across the prior distribution will be used.

Using the specific type of model, either the MNL or RPL probs will be returned.

Value

A matrix of probabilities for each alternative and choice task.


spdesign documentation built on July 2, 2026, 5:06 p.m.