unlisted_levels: Find attributes with level occurrences and levels that are...

View source: R/assertions.R

unlisted_levelsR Documentation

Find attributes with level occurrences and levels that are not listed

Description

A supplied candidate set may contain attribute levels that are not listed in the utility functions. This is only a problem for attributes with level occurrences specified, because occurrences can only be counted for listed levels.

Usage

unlisted_levels(utility, candidate_set, rows)

Arguments

utility

A named list of utility functions. See the examples and the vignette for examples of how to define these correctly for different types of experimental designs.

candidate_set

A candidate set in wide format

rows

Number of rows in the design

Value

A character vector with the names of the attributes with level occurrences specified, where the candidate set contains levels that are not listed in the utility functions. Empty if there are none.


spdesign documentation built on Oct. 6, 2026, 9:07 a.m.