| as_whole_word | R Documentation |
Creates regular expressions that match names as whole words, so that e.g. x1 does not match x10, b_x1 or alt1_x1. Names in the utility functions only contain letters, digits and underscores.
as_whole_word(name)
name |
A character vector of names |
A character vector of regular expressions
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.