View source: R/candidate-set.R
| define_profiles | R Documentation |
Defines the profiles of each alternative as the full factorial of its
attribute levels, with the exclusions that only refer to that alternative
applied, and finds the groups of exchangeable alternatives. See
build_candidate_set.
define_profiles(utility, exclusions = list())
utility |
A named list of utility functions. See the examples and the vignette for examples of how to define these correctly for different types of experimental designs. |
exclusions |
A list of exclusions Often this list will be pulled directly from the list of options or it is a modified list of exclusions |
A list with the profiles of each alternative, the groups of exchangeable alternatives and the exclusions across alternatives
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.