View source: R/exclusions-and-conditions.R
| exclude | R Documentation |
Each exclusion is evaluated with the columns of the candidate set as variables, and the rows where it is TRUE are removed.
exclude(candidate_set, exclusions)
candidate_set |
A matrix or data frame in the "wide" format containing
all permitted combinations of attributes. The default is NULL. If no
candidate set is provided, then it is built from the utility functions
subject to specified exclusions with |
exclusions |
A list of exclusions Often this list will be pulled directly from the list of options or it is a modified list of exclusions |
A restricted candidate set
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.