View source: R/full-factorial.R
| full_factorial | R Documentation |
This function is deprecated and will be removed in a future version. Use
build_candidate_set to build a candidate set from the utility
functions, or expand.grid to create the full factorial of a
list of attributes with levels that are different from those in the utility
functions.
full_factorial(attrs)
attrs |
A named list of attributes and their levels |
The function is a wrapper around expand.grid and generates the
full factorial given the supplied attributes.
A data frame containing the full factorial
attrs <- list(
a1 = 1:5,
a2 = c(0, 1)
)
# Instead of full_factorial(attrs)
expand.grid(attrs)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.