| invalid_dummy_coding | R Documentation |
Dummy-coded attributes must have the levels 1, 2, ..., K, where 1 is the base level, and exactly K - 1 priors, one for each level except the base level. Only the number of levels matters for the design, and using 1, 2, ..., K ensures that the expanded dummy-coded attributes and priors are named and ordered consistently.
invalid_dummy_coding(x)
x |
An object of class utility |
A character vector with the names of dummy-coded attributes that are not correctly specified. Empty if there are none.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.