level_occurrences_specified: Test whether level occurrences are specified in the utility...

View source: R/assertions.R

level_occurrences_specifiedR Documentation

Test whether level occurrences are specified in the utility functions

Description

Test whether level occurrences are specified in the utility functions

Usage

level_occurrences_specified(utility)

Arguments

utility

A named list of utility functions. See the examples and the vignette for examples of how to define these correctly for different types of experimental designs.

Value

A boolean equal to TRUE if level occurrences are specified and FALSE otherwise


spdesign documentation built on July 2, 2026, 5:06 p.m.