| level_occurrences_specified | R Documentation |
Test whether level occurrences are specified in the utility functions
level_occurrences_specified(utility)
utility |
A named list of utility functions. See the examples and the vignette for examples of how to define these correctly for different types of experimental designs. |
A boolean equal to TRUE if level occurrences are specified and FALSE otherwise
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.