| pair_param_terms | R Documentation |
Splits each updated utility function into its additive terms and pairs each
term with its parameter, e.g. "b_x1x2 * I(alt1_x1 * alt1_x2)". The function
is used on the output of update_utility, where dummy-coded
attributes are already expanded.
pair_param_terms(x)
x |
A list of updated utility functions returned by
|
A list with one named character vector per utility function. The values are the parameter names and the names are the terms, both without whitespace.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.