| unlisted_levels | R Documentation |
A supplied candidate set may contain attribute levels that are not listed in the utility functions. This is only a problem for attributes with level occurrences specified, because occurrences can only be counted for listed levels.
unlisted_levels(utility, candidate_set, rows)
utility |
A named list of utility functions. See the examples and the vignette for examples of how to define these correctly for different types of experimental designs. |
candidate_set |
A candidate set in wide format |
rows |
Number of rows in the design |
A character vector with the names of the attributes with level occurrences specified, where the candidate set contains levels that are not listed in the utility functions. Empty if there are none.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.