| utility_formula | R Documentation |
Create formulas from the utility functions such that we can create correct model matrices. The formula of each utility function contains its terms, i.e. the utility function without the parameters.
utility_formula(x)
x |
An object of class utility |
Note that the formulas are created from the cleaned utility expression and
**not** the updated utility expression. This is because we are converting
dummy coded attributes to factors prior to calling model.matrix.
This ensures that dummy coded attributes are correctly returned with the
model matrix.
A list of formula expressions for the utility functions
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.